@@ -1390,6 +1390,72 @@ class FleetManagementServiceClient(metaclass=FleetManagementServiceClientMeta):
         # Done; return the response.
         return response
 
+    def upload_fleet_list(self,
+            request: Union[service.GetFleetListRequest, dict] = None,
+            *,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
+            timeout: float = None,
+            metadata: Sequence[Tuple[str, str]] = (),
+            ) -> service.EmptyResponse:
+        r"""Uploads file containing fleet data to be parsed into
+        a batch of vessels.
+
+
+        .. code-block:: python
+
+            from oceanbolt.com import fleetmanagement_v3
+
+            def sample_upload_fleet_list():
+                # Create a client
+                client = fleetmanagement_v3.FleetManagementServiceClient()
+
+                # Initialize request argument(s)
+                request = fleetmanagement_v3.GetFleetListRequest(
+                )
+
+                # Make the request
+                response = client.upload_fleet_list(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.fleetmanagement_v3.types.GetFleetListRequest, dict]):
+                The request object. Request object for parsing a file
+                into a fleet
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            oceanbolt.com.fleetmanagement_v3.types.EmptyResponse:
+                Empty response object
+        """
+        # Create or coerce a protobuf request object.
+        # Minor optimization to avoid making a copy if the user passes
+        # in a service.GetFleetListRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, service.GetFleetListRequest):
+            request = service.GetFleetListRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.upload_fleet_list]
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
     def __enter__(self):
         return self
 
