@@ -16,6 +16,7 @@
 import proto  # type: ignore
 
 from google.protobuf import wrappers_pb2  # type: ignore
+from oceanbolt.com.ptypes.filters import vessel_filter_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -120,6 +121,8 @@ class GetPortCallsRequest(proto.Message):
             DWT range to filter on. Example: [60000,90000] - this would
             filter only to only include dwt between 60k and 90k (both
             values inclusive).
+        vessel_filter (oceanbolt.com.ptypes.filters.vessel_filter_pb2.VesselFilter):
+            Specifies vessel parameters to filter on.
     """
 
     imo = proto.RepeatedField(
@@ -214,6 +217,11 @@ class GetPortCallsRequest(proto.Message):
         proto.DOUBLE,
         number=37,
     )
+    vessel_filter = proto.Field(
+        proto.MESSAGE,
+        number=38,
+        message=vessel_filter_pb2.VesselFilter,
+    )
 
 
 class GetPortCallsResponse(proto.Message):
