@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,29 +13,32 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions # type: ignore
-from google.api_core import exceptions                 # type: ignore
-from google.api_core import gapic_v1                   # type: ignore
-from google.api_core import retry as retries           # type: ignore
-from google.auth import credentials                    # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.auth import credentials as ga_credentials   # type: ignore
 from google.oauth2 import service_account              # type: ignore
 
-from oceanbolt.com.tonnage_v3.types import service
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from oceanbolt.com.tonnage_v3.types import service
 from .transports.base import TonnageServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import TonnageServiceGrpcAsyncIOTransport
 from .client import TonnageServiceClient
 
 
 class TonnageServiceAsyncClient:
-    """TonnageService provides am API service to get tonnage data"""
+    """TonnageService provides an API service to get tonnage data"""
 
     _client: TonnageServiceClient
 
@@ -45,26 +47,85 @@ class TonnageServiceAsyncClient:
 
     common_billing_account_path = staticmethod(TonnageServiceClient.common_billing_account_path)
     parse_common_billing_account_path = staticmethod(TonnageServiceClient.parse_common_billing_account_path)
-
     common_folder_path = staticmethod(TonnageServiceClient.common_folder_path)
     parse_common_folder_path = staticmethod(TonnageServiceClient.parse_common_folder_path)
-
     common_organization_path = staticmethod(TonnageServiceClient.common_organization_path)
     parse_common_organization_path = staticmethod(TonnageServiceClient.parse_common_organization_path)
-
     common_project_path = staticmethod(TonnageServiceClient.common_project_path)
     parse_common_project_path = staticmethod(TonnageServiceClient.parse_common_project_path)
-
     common_location_path = staticmethod(TonnageServiceClient.common_location_path)
     parse_common_location_path = staticmethod(TonnageServiceClient.parse_common_location_path)
 
-    from_service_account_info = TonnageServiceClient.from_service_account_info
-    from_service_account_file = TonnageServiceClient.from_service_account_file
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            TonnageServiceAsyncClient: The constructed client.
+        """
+        return TonnageServiceClient.from_service_account_info.__func__(TonnageServiceAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            TonnageServiceAsyncClient: The constructed client.
+        """
+        return TonnageServiceClient.from_service_account_file.__func__(TonnageServiceAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(cls, client_options: Optional[ClientOptions] = None):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return TonnageServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> TonnageServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             TonnageServiceTransport: The transport used by the client instance.
@@ -74,12 +135,12 @@ class TonnageServiceAsyncClient:
     get_transport_class = functools.partial(type(TonnageServiceClient).get_transport_class, type(TonnageServiceClient))
 
     def __init__(self, *,
-            credentials: credentials.Credentials = None,
-            transport: Union[str, TonnageServiceTransport] = 'grpc_asyncio',
+            credentials: ga_credentials.Credentials = None,
+            transport: Union[str, TonnageServiceTransport] = "grpc_asyncio",
             client_options: ClientOptions = None,
             client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
             ) -> None:
-        """Instantiate the tonnage service client.
+        """Instantiates the tonnage service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -111,7 +172,6 @@ class TonnageServiceAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = TonnageServiceClient(
             credentials=credentials,
             transport=transport,
@@ -121,19 +181,36 @@ class TonnageServiceAsyncClient:
         )
 
     async def get_tonnage_zone_count(self,
-            request: service.GetTonnageDataRequest = None,
+            request: Union[service.GetTonnageDataRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTonnageZoneCountResponse:
         r"""Fetches tonnage counts timeseries.
 
+        .. code-block:: python
+
+            from oceanbolt.com import tonnage_v3
+
+            def sample_get_tonnage_zone_count():
+                # Create a client
+                client = tonnage_v3.TonnageServiceClient()
+
+                # Initialize request argument(s)
+                request = tonnage_v3.GetTonnageDataRequest(
+                )
+
+                # Make the request
+                response = client.get_tonnage_zone_count(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`oceanbolt.com.tonnage_v3.types.GetTonnageDataRequest`):
+            request (Union[oceanbolt.com.tonnage_v3.types.GetTonnageDataRequest, dict]):
                 The request object. Request object for getting tonnage
                 zone data and fleet speed data.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -147,7 +224,6 @@ class TonnageServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.GetTonnageDataRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -170,19 +246,36 @@ class TonnageServiceAsyncClient:
         return response
 
     async def get_tonnage_fleet_speed(self,
-            request: service.GetTonnageDataRequest = None,
+            request: Union[service.GetTonnageDataRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetFleetSpeedResponse:
         r"""Fetches fleet speed timeseries.
 
+        .. code-block:: python
+
+            from oceanbolt.com import tonnage_v3
+
+            def sample_get_tonnage_fleet_speed():
+                # Create a client
+                client = tonnage_v3.TonnageServiceClient()
+
+                # Initialize request argument(s)
+                request = tonnage_v3.GetTonnageDataRequest(
+                )
+
+                # Make the request
+                response = client.get_tonnage_fleet_speed(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`oceanbolt.com.tonnage_v3.types.GetTonnageDataRequest`):
+            request (Union[oceanbolt.com.tonnage_v3.types.GetTonnageDataRequest, dict]):
                 The request object. Request object for getting tonnage
                 zone data and fleet speed data.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -194,7 +287,6 @@ class TonnageServiceAsyncClient:
                 Response object for FleetSpeed
         """
         # Create or coerce a protobuf request object.
-
         request = service.GetTonnageDataRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -217,19 +309,36 @@ class TonnageServiceAsyncClient:
         return response
 
     async def get_global_tonnage_status(self,
-            request: service.GetTonnageDataRequest = None,
+            request: Union[service.GetTonnageDataRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetGlobalTonnageStatusResponse:
         r"""Fetches global tonnage status timeseries.
 
+        .. code-block:: python
+
+            from oceanbolt.com import tonnage_v3
+
+            def sample_get_global_tonnage_status():
+                # Create a client
+                client = tonnage_v3.TonnageServiceClient()
+
+                # Initialize request argument(s)
+                request = tonnage_v3.GetTonnageDataRequest(
+                )
+
+                # Make the request
+                response = client.get_global_tonnage_status(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`oceanbolt.com.tonnage_v3.types.GetTonnageDataRequest`):
+            request (Union[oceanbolt.com.tonnage_v3.types.GetTonnageDataRequest, dict]):
                 The request object. Request object for getting tonnage
                 zone data and fleet speed data.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -241,7 +350,6 @@ class TonnageServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.GetTonnageDataRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -264,9 +372,9 @@ class TonnageServiceAsyncClient:
         return response
 
     async def get_tonnage_fleet_status(self,
-            request: service.GetTonnageFleetRequest = None,
+            request: Union[service.GetTonnageFleetRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTonnageFleetStatusResponse:
@@ -274,11 +382,29 @@ class TonnageServiceAsyncClient:
         have developed over time. This timeseries shows number
         of active vessels on the water at any given time.
 
+
+        .. code-block:: python
+
+            from oceanbolt.com import tonnage_v3
+
+            def sample_get_tonnage_fleet_status():
+                # Create a client
+                client = tonnage_v3.TonnageServiceClient()
+
+                # Initialize request argument(s)
+                request = tonnage_v3.GetTonnageFleetRequest(
+                )
+
+                # Make the request
+                response = client.get_tonnage_fleet_status(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`oceanbolt.com.tonnage_v3.types.GetTonnageFleetRequest`):
+            request (Union[oceanbolt.com.tonnage_v3.types.GetTonnageFleetRequest, dict]):
                 The request object. Request object for
                 GetTonnageFleetStatus and GetTonnageFleetGrowth
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -292,7 +418,6 @@ class TonnageServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.GetTonnageFleetRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -315,9 +440,9 @@ class TonnageServiceAsyncClient:
         return response
 
     async def get_tonnage_fleet_growth(self,
-            request: service.GetTonnageFleetRequest = None,
+            request: Union[service.GetTonnageFleetRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTonnageFleetGrowthResponse:
@@ -326,11 +451,29 @@ class TonnageServiceAsyncClient:
         of vessels added to/removed from the fleet during any
         given period.
 
+
+        .. code-block:: python
+
+            from oceanbolt.com import tonnage_v3
+
+            def sample_get_tonnage_fleet_growth():
+                # Create a client
+                client = tonnage_v3.TonnageServiceClient()
+
+                # Initialize request argument(s)
+                request = tonnage_v3.GetTonnageFleetRequest(
+                )
+
+                # Make the request
+                response = client.get_tonnage_fleet_growth(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`oceanbolt.com.tonnage_v3.types.GetTonnageFleetRequest`):
+            request (Union[oceanbolt.com.tonnage_v3.types.GetTonnageFleetRequest, dict]):
                 The request object. Request object for
                 GetTonnageFleetStatus and GetTonnageFleetGrowth
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -344,7 +487,6 @@ class TonnageServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.GetTonnageFleetRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -367,9 +509,9 @@ class TonnageServiceAsyncClient:
         return response
 
     async def get_tonnage_chinese_waters(self,
-            request: service.TonnageChineseWatersRequest = None,
+            request: Union[service.TonnageChineseWatersRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.TonnageChineseWatersResponse:
@@ -378,11 +520,29 @@ class TonnageServiceAsyncClient:
         trading inside and outside of Chinese waters
         respectively.
 
+
+        .. code-block:: python
+
+            from oceanbolt.com import tonnage_v3
+
+            def sample_get_tonnage_chinese_waters():
+                # Create a client
+                client = tonnage_v3.TonnageServiceClient()
+
+                # Initialize request argument(s)
+                request = tonnage_v3.TonnageChineseWatersRequest(
+                )
+
+                # Make the request
+                response = client.get_tonnage_chinese_waters(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`oceanbolt.com.tonnage_v3.types.TonnageChineseWatersRequest`):
+            request (Union[oceanbolt.com.tonnage_v3.types.TonnageChineseWatersRequest, dict]):
                 The request object. Request object for
                 TonnageChineseWaters
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -396,7 +556,6 @@ class TonnageServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.TonnageChineseWatersRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -419,19 +578,37 @@ class TonnageServiceAsyncClient:
         return response
 
     async def get_tonnage_zone_changes(self,
-            request: service.GetTonnageZoneChangesRequest = None,
+            request: Union[service.GetTonnageZoneChangesRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTonnageZoneChangesResponse:
         r"""Provides timeseries data on the number of vessels
         that cross zone boundaries during any given period.
 
-        Args:
-            request (:class:`oceanbolt.com.tonnage_v3.types.GetTonnageZoneChangesRequest`):
-                The request object. Request object for TonnageZoneChange
 
+        .. code-block:: python
+
+            from oceanbolt.com import tonnage_v3
+
+            def sample_get_tonnage_zone_changes():
+                # Create a client
+                client = tonnage_v3.TonnageServiceClient()
+
+                # Initialize request argument(s)
+                request = tonnage_v3.GetTonnageZoneChangesRequest(
+                )
+
+                # Make the request
+                response = client.get_tonnage_zone_changes(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.tonnage_v3.types.GetTonnageZoneChangesRequest, dict]):
+                The request object. Request object for TonnageZoneChange
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -443,7 +620,6 @@ class TonnageServiceAsyncClient:
                 Response object for TonnageZoneChange
         """
         # Create or coerce a protobuf request object.
-
         request = service.GetTonnageZoneChangesRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -466,19 +642,37 @@ class TonnageServiceAsyncClient:
         return response
 
     async def get_tonnage_basin_count(self,
-            request: service.GetTonnageBasinRequest = None,
+            request: Union[service.GetTonnageBasinRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTonnageBasinResponse:
         r"""Provides timeseries data on the number of vessels
         that are within the four major basins.
 
-        Args:
-            request (:class:`oceanbolt.com.tonnage_v3.types.GetTonnageBasinRequest`):
-                The request object. GetTonnageBasin
 
+        .. code-block:: python
+
+            from oceanbolt.com import tonnage_v3
+
+            def sample_get_tonnage_basin_count():
+                # Create a client
+                client = tonnage_v3.TonnageServiceClient()
+
+                # Initialize request argument(s)
+                request = tonnage_v3.GetTonnageBasinRequest(
+                )
+
+                # Make the request
+                response = client.get_tonnage_basin_count(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.tonnage_v3.types.GetTonnageBasinRequest, dict]):
+                The request object. GetTonnageBasin
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -490,7 +684,6 @@ class TonnageServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.GetTonnageBasinRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -512,16 +705,16 @@ class TonnageServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def __aenter__(self):
+        return self
 
-
-
-
-
+    async def __aexit__(self, exc_type, exc, tb):
+        await self.transport.close()
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
-            'oceanbolt-com-tonnage',
+            "oceanbolt-com-tonnage",
         ).version,
     )
 except pkg_resources.DistributionNotFound:
@@ -529,5 +722,5 @@ except pkg_resources.DistributionNotFound:
 
 
 __all__ = (
-    'TonnageServiceAsyncClient',
+    "TonnageServiceAsyncClient",
 )
