@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,22 +13,25 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions # type: ignore
-from google.api_core import exceptions                 # type: ignore
-from google.api_core import gapic_v1                   # type: ignore
-from google.api_core import retry as retries           # type: ignore
-from google.auth import credentials                    # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.auth import credentials as ga_credentials   # type: ignore
 from google.oauth2 import service_account              # type: ignore
 
-from oceanbolt.com.tradeflows_v3.types import service
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from oceanbolt.com.tradeflows_v3.types import service
 from .transports.base import TradeFlowServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import TradeFlowServiceGrpcAsyncIOTransport
 from .client import TradeFlowServiceClient
@@ -45,26 +47,85 @@ class TradeFlowServiceAsyncClient:
 
     common_billing_account_path = staticmethod(TradeFlowServiceClient.common_billing_account_path)
     parse_common_billing_account_path = staticmethod(TradeFlowServiceClient.parse_common_billing_account_path)
-
     common_folder_path = staticmethod(TradeFlowServiceClient.common_folder_path)
     parse_common_folder_path = staticmethod(TradeFlowServiceClient.parse_common_folder_path)
-
     common_organization_path = staticmethod(TradeFlowServiceClient.common_organization_path)
     parse_common_organization_path = staticmethod(TradeFlowServiceClient.parse_common_organization_path)
-
     common_project_path = staticmethod(TradeFlowServiceClient.common_project_path)
     parse_common_project_path = staticmethod(TradeFlowServiceClient.parse_common_project_path)
-
     common_location_path = staticmethod(TradeFlowServiceClient.common_location_path)
     parse_common_location_path = staticmethod(TradeFlowServiceClient.parse_common_location_path)
 
-    from_service_account_info = TradeFlowServiceClient.from_service_account_info
-    from_service_account_file = TradeFlowServiceClient.from_service_account_file
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            TradeFlowServiceAsyncClient: The constructed client.
+        """
+        return TradeFlowServiceClient.from_service_account_info.__func__(TradeFlowServiceAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            TradeFlowServiceAsyncClient: The constructed client.
+        """
+        return TradeFlowServiceClient.from_service_account_file.__func__(TradeFlowServiceAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(cls, client_options: Optional[ClientOptions] = None):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return TradeFlowServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> TradeFlowServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             TradeFlowServiceTransport: The transport used by the client instance.
@@ -74,12 +135,12 @@ class TradeFlowServiceAsyncClient:
     get_transport_class = functools.partial(type(TradeFlowServiceClient).get_transport_class, type(TradeFlowServiceClient))
 
     def __init__(self, *,
-            credentials: credentials.Credentials = None,
-            transport: Union[str, TradeFlowServiceTransport] = 'grpc_asyncio',
+            credentials: ga_credentials.Credentials = None,
+            transport: Union[str, TradeFlowServiceTransport] = "grpc_asyncio",
             client_options: ClientOptions = None,
             client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
             ) -> None:
-        """Instantiate the trade flow service client.
+        """Instantiates the trade flow service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -111,7 +172,6 @@ class TradeFlowServiceAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = TradeFlowServiceClient(
             credentials=credentials,
             transport=transport,
@@ -121,9 +181,9 @@ class TradeFlowServiceAsyncClient:
         )
 
     async def get_trade_flows(self,
-            request: service.TradeFlowDataRequest = None,
+            request: Union[service.TradeFlowDataRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTradeFlowsResponse:
@@ -133,11 +193,29 @@ class TradeFlowServiceAsyncClient:
         page to return. It is also possible to set the number of
         voyages to return per query.
 
+
+        .. code-block:: python
+
+            from oceanbolt.com import tradeflows_v3
+
+            def sample_get_trade_flows():
+                # Create a client
+                client = tradeflows_v3.TradeFlowServiceClient()
+
+                # Initialize request argument(s)
+                request = tradeflows_v3.TradeFlowDataRequest(
+                )
+
+                # Make the request
+                response = client.get_trade_flows(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest`):
+            request (Union[oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest, dict]):
                 The request object. Trade flow data requests object.
                 This is shared between all trade flows queries
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -151,7 +229,6 @@ class TradeFlowServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.TradeFlowDataRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -174,19 +251,36 @@ class TradeFlowServiceAsyncClient:
         return response
 
     async def get_trade_flow_aggregation(self,
-            request: service.TradeFlowDataRequest = None,
+            request: Union[service.TradeFlowDataRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTradeFlowAggregationResponse:
         r"""Aggregates tradeflow data across multiple dimensions.
 
+        .. code-block:: python
+
+            from oceanbolt.com import tradeflows_v3
+
+            def sample_get_trade_flow_aggregation():
+                # Create a client
+                client = tradeflows_v3.TradeFlowServiceClient()
+
+                # Initialize request argument(s)
+                request = tradeflows_v3.TradeFlowDataRequest(
+                )
+
+                # Make the request
+                response = client.get_trade_flow_aggregation(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest`):
+            request (Union[oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest, dict]):
                 The request object. Trade flow data requests object.
                 This is shared between all trade flows queries
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -198,7 +292,6 @@ class TradeFlowServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.TradeFlowDataRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -221,19 +314,36 @@ class TradeFlowServiceAsyncClient:
         return response
 
     async def get_trade_flow_timeseries(self,
-            request: service.TradeFlowDataRequest = None,
+            request: Union[service.TradeFlowDataRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTradeFlowTimeseriesResponse:
         r"""Gets aggregated trade flow timeseries by period.
 
+        .. code-block:: python
+
+            from oceanbolt.com import tradeflows_v3
+
+            def sample_get_trade_flow_timeseries():
+                # Create a client
+                client = tradeflows_v3.TradeFlowServiceClient()
+
+                # Initialize request argument(s)
+                request = tradeflows_v3.TradeFlowDataRequest(
+                )
+
+                # Make the request
+                response = client.get_trade_flow_timeseries(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest`):
+            request (Union[oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest, dict]):
                 The request object. Trade flow data requests object.
                 This is shared between all trade flows queries
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -247,7 +357,6 @@ class TradeFlowServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.TradeFlowDataRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -270,20 +379,38 @@ class TradeFlowServiceAsyncClient:
         return response
 
     async def get_trade_flow_on_the_water(self,
-            request: service.TradeFlowDataRequest = None,
+            request: Union[service.TradeFlowDataRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTradeFlowTimeseriesResponse:
         r"""Gets aggregated trade flow timeseries (on the water)
         by period.
 
+
+        .. code-block:: python
+
+            from oceanbolt.com import tradeflows_v3
+
+            def sample_get_trade_flow_on_the_water():
+                # Create a client
+                client = tradeflows_v3.TradeFlowServiceClient()
+
+                # Initialize request argument(s)
+                request = tradeflows_v3.TradeFlowDataRequest(
+                )
+
+                # Make the request
+                response = client.get_trade_flow_on_the_water(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest`):
+            request (Union[oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest, dict]):
                 The request object. Trade flow data requests object.
                 This is shared between all trade flows queries
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -297,7 +424,6 @@ class TradeFlowServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.TradeFlowDataRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -320,20 +446,38 @@ class TradeFlowServiceAsyncClient:
         return response
 
     async def get_trade_flow_histogram(self,
-            request: service.TradeFlowDataRequest = None,
+            request: Union[service.TradeFlowDataRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTradeFlowHistogramResponse:
         r"""GetTradeFlowHistogramValues gets trade flow histogram
         values by grouping.
 
+
+        .. code-block:: python
+
+            from oceanbolt.com import tradeflows_v3
+
+            def sample_get_trade_flow_histogram():
+                # Create a client
+                client = tradeflows_v3.TradeFlowServiceClient()
+
+                # Initialize request argument(s)
+                request = tradeflows_v3.TradeFlowDataRequest(
+                )
+
+                # Make the request
+                response = client.get_trade_flow_histogram(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest`):
+            request (Union[oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest, dict]):
                 The request object. Trade flow data requests object.
                 This is shared between all trade flows queries
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -345,7 +489,6 @@ class TradeFlowServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.TradeFlowDataRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -368,9 +511,9 @@ class TradeFlowServiceAsyncClient:
         return response
 
     async def get_location_volume(self,
-            request: service.TradeFlowDataRequest = None,
+            request: Union[service.TradeFlowDataRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetLocationVolumeResponse:
@@ -378,11 +521,29 @@ class TradeFlowServiceAsyncClient:
         (port/berth/country/region) flow stats for the given
         filter parameters
 
+
+        .. code-block:: python
+
+            from oceanbolt.com import tradeflows_v3
+
+            def sample_get_location_volume():
+                # Create a client
+                client = tradeflows_v3.TradeFlowServiceClient()
+
+                # Initialize request argument(s)
+                request = tradeflows_v3.TradeFlowDataRequest(
+                )
+
+                # Make the request
+                response = client.get_location_volume(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest`):
+            request (Union[oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest, dict]):
                 The request object. Trade flow data requests object.
                 This is shared between all trade flows queries
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -394,7 +555,6 @@ class TradeFlowServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.TradeFlowDataRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -417,20 +577,38 @@ class TradeFlowServiceAsyncClient:
         return response
 
     async def get_trade_lane_metrics(self,
-            request: service.TradeFlowDataRequest = None,
+            request: Union[service.TradeFlowDataRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.GetTradeLaneMetricsResponse:
         r"""GetTradeflowModelVoyage gets trade flow model voyage
         values by grouping
 
+
+        .. code-block:: python
+
+            from oceanbolt.com import tradeflows_v3
+
+            def sample_get_trade_lane_metrics():
+                # Create a client
+                client = tradeflows_v3.TradeFlowServiceClient()
+
+                # Initialize request argument(s)
+                request = tradeflows_v3.TradeFlowDataRequest(
+                )
+
+                # Make the request
+                response = client.get_trade_lane_metrics(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest`):
+            request (Union[oceanbolt.com.tradeflows_v3.types.TradeFlowDataRequest, dict]):
                 The request object. Trade flow data requests object.
                 This is shared between all trade flows queries
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -442,7 +620,6 @@ class TradeFlowServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.TradeFlowDataRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -464,16 +641,16 @@ class TradeFlowServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def __aenter__(self):
+        return self
 
-
-
-
-
+    async def __aexit__(self, exc_type, exc, tb):
+        await self.transport.close()
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
-            'oceanbolt-com-tradeflows',
+            "oceanbolt-com-tradeflows",
         ).version,
     )
 except pkg_resources.DistributionNotFound:
@@ -481,5 +658,5 @@ except pkg_resources.DistributionNotFound:
 
 
 __all__ = (
-    'TradeFlowServiceAsyncClient',
+    "TradeFlowServiceAsyncClient",
 )
