@@ -32,10 +32,12 @@ from google.api_core import path_template
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.oauth2 import service_account
+from google.protobuf import wrappers_pb2  # type: ignore
 from oceanbolt.com.congestion_v3.services.congestion_service import CongestionServiceAsyncClient
 from oceanbolt.com.congestion_v3.services.congestion_service import CongestionServiceClient
 from oceanbolt.com.congestion_v3.services.congestion_service import transports
 from oceanbolt.com.congestion_v3.types import service
+from oceanbolt.com.ptypes.filters import vessel_filter_pb2  # type: ignore
 import google.auth
 
 
